package com.ruoyi.ems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.ElecExpendForecastMapper;
import com.ruoyi.ems.domain.ElecExpendForecast;
import com.ruoyi.ems.service.IElecExpendForecastService;

/**
 * 电力消耗预测Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-12
 */
@Service
public class ElecExpendForecastServiceImpl implements IElecExpendForecastService
{
    @Autowired
    private ElecExpendForecastMapper emsElecExpendForecastMapper;

    /**
     * 查询电力消耗预测
     * 
     * @param id 电力消耗预测主键
     * @return 电力消耗预测
     */
    @Override
    public ElecExpendForecast selectElecExpendForecastById(Long id)
    {
        return emsElecExpendForecastMapper.selectElecExpendForecastById(id);
    }

    /**
     * 查询电力消耗预测列表
     * 
     * @param admEmsElecExpendForecast 电力消耗预测
     * @return 电力消耗预测
     */
    @Override
    public List<ElecExpendForecast> selectElecExpendForecastList(ElecExpendForecast admEmsElecExpendForecast)
    {
        return emsElecExpendForecastMapper.selectElecExpendForecastList(admEmsElecExpendForecast);
    }

    /**
     * 新增电力消耗预测
     * 
     * @param admEmsElecExpendForecast 电力消耗预测
     * @return 结果
     */
    @Override
    public int insertElecExpendForecast(ElecExpendForecast admEmsElecExpendForecast)
    {
        return emsElecExpendForecastMapper.insertElecExpendForecast(admEmsElecExpendForecast);
    }

    /**
     * 修改电力消耗预测
     * 
     * @param admEmsElecExpendForecast 电力消耗预测
     * @return 结果
     */
    @Override
    public int updateElecExpendForecast(ElecExpendForecast admEmsElecExpendForecast)
    {
        return emsElecExpendForecastMapper.updateElecExpendForecast(admEmsElecExpendForecast);
    }

    /**
     * 批量删除电力消耗预测
     * 
     * @param ids 需要删除的电力消耗预测主键
     * @return 结果
     */
    @Override
    public int deleteElecExpendForecastByIds(Long[] ids)
    {
        return emsElecExpendForecastMapper.deleteElecExpendForecastByIds(ids);
    }

    /**
     * 删除电力消耗预测信息
     * 
     * @param id 电力消耗预测主键
     * @return 结果
     */
    @Override
    public int deleteElecExpendForecastById(Long id)
    {
        return emsElecExpendForecastMapper.deleteElecExpendForecastById(id);
    }
}
