package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.ElecExpendForecast;

/**
 * 电力消耗预测Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-12
 */
public interface ElecExpendForecastMapper
{
    /**
     * 查询电力消耗预测
     * 
     * @param id 电力消耗预测主键
     * @return 电力消耗预测
     */
     ElecExpendForecast selectElecExpendForecastById(Long id);

    /**
     * 查询电力消耗预测列表
     * 
     * @param emsElecExpendForecast 电力消耗预测
     * @return 电力消耗预测集合
     */
     List<ElecExpendForecast> selectElecExpendForecastList(ElecExpendForecast emsElecExpendForecast);

    /**
     * 新增电力消耗预测
     * 
     * @param emsElecExpendForecast 电力消耗预测
     * @return 结果
     */
     int insertElecExpendForecast(ElecExpendForecast emsElecExpendForecast);

    /**
     * 修改电力消耗预测
     * 
     * @param emsElecExpendForecast 电力消耗预测
     * @return 结果
     */
     int updateElecExpendForecast(ElecExpendForecast emsElecExpendForecast);

    /**
     * 删除电力消耗预测
     * 
     * @param id 电力消耗预测主键
     * @return 结果
     */
     int deleteElecExpendForecastById(Long id);

    /**
     * 批量删除电力消耗预测
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteElecExpendForecastByIds(Long[] ids);
}
